@@ -844,11 +844,16 @@ class DobissAPI:
                 ws = await self._session.ws_connect(self._ws_url, headers=headers)
                 while not self._stop_monitoring:
                     try:
-                        response = await ws.receive_json()
-                        # logger.debug("received ws message")
-                        logger.debug(f"Status update pushed: {response}")
-                        if response is not None:
-                            await self.update_from_status(response)
+                        import json
+
+                        data = await ws.receive_str()
+                        logger.debug(f"Received websocket communication: {data}")
+                        # response = await ws.receive_json()
+                        if data:
+                            response = json.loads(data)
+                            logger.debug(f"Status update pushed: {response}")
+                            if response is not None:
+                                await self.update_from_status(response)
                     except TypeError as error:
                         logger.exception(f"dobiss monitor exception: {repr(error)}")
                         if not ws.closed:
